from earthdiagnostics import Utils, cdftools, TempFile
from autosubmit.config.log import Log
import os
import shutil


class Salinity(object):
    """
    Class containing all the diagnostics related to salinity
    """



    @staticmethod
    def mixed_layer_content(input_file, mlotst_file, output_file):
        """
        Compute mixed layer heat and salt content

        Created in February 2012      Author : vguemas@ic3.cat

        :param mlotst_file:
        :param input_file: input grid_T file name
        :param output_file: output file name  (=> 2D x-y )
        :return:
        """
        nco = Utils.nco
        cdo = Utils.cdo
        input_scratch = TempFile.get()
        shutil.copy(input_file, input_scratch)
        Utils.nco.ncks(input=mlotst_file, output=input_scratch, options='-A -v mlotst')

        ntime = int(cdo.ntime(input=input_scratch)[0])
        files = list()

        for time in range(ntime):
            Log.info('Running time {0}', time)
            temp = TempFile.get()
            nco.ncks(input=input_scratch, output=temp, options='-O -d time,{0}'.format(time))
            Log.info('Computing salt content')
            cdftools.run('cdfmxlsaltc', input=temp)
            Utils.move_file('mxlsaltc.nc', temp)
            files.append(temp)

        temp = TempFile.get()
        cdo.cat(input=' '.join(files), output=temp,)
        nco.ncks(input=input_scratch, output=temp, options='-A -v time')

        for temp_file in files:
            os.remove(temp_file)
        os.remove(input_scratch)

        Utils.rename_variables(temp, {'x': 'i', 'y': 'j', 'somxlsaltc': 'mlotstsc'}, False, True)
        Utils.setminmax(temp, 'mlotstsc')
        Utils.move_file(temp, output_file)
